0.9.9 API documentation: GLM_EXT_quaternion_trigonometric

| 0.9.9 API documentation

- Main Page
- Modules
- Files

Functions
GLM_EXT_quaternion_trigonometric
Stable extensions

Provides trigonometric functions for quaternion types. More...

## Functions
template<typename T , qualifier Q>
GLM_FUNC_DECL T | angle (qua< T, Q > const &x)
| Returns the quaternion rotation angle. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL qua< T, Q > | angleAxis (T const &angle, vec< 3, T, Q > const &axis)
| Build a quaternion from an angle and a normalized axis. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL vec< 3, T, Q > | axis (qua< T, Q > const &x)
| Returns the q rotation axis. More...

## Detailed Description

Provides trigonometric functions for quaternion types.

Include <glm/ext/quaternion_trigonometric.hpp> to use the features of this extension.

See also
  GLM_EXT_quaternion_float
  GLM_EXT_quaternion_double
  GLM_EXT_quaternion_exponential
  GLM_EXT_quaternion_geometric
  GLM_EXT_quaternion_relational
  GLM_EXT_quaternion_transform

## Function Documentation

GLM_FUNC_DECL T glm::angle | ( | qua< T, Q > const & | x | ) |

Returns the quaternion rotation angle.

Template Parameters

  T | A floating-point scalar type
  Q | A value from qualifier enum

GLM_FUNC_DECL qua<T, Q> glm::angleAxis | ( | T const & | angle,
|  | vec< 3, T, Q > const & | axis
| ) |  |

Build a quaternion from an angle and a normalized axis.

Parameters

  angle | Angle expressed in radians.
  axis | Axis of the quaternion, must be normalized.

Template Parameters

  T | A floating-point scalar type
  Q | A value from qualifier enum

GLM_FUNC_DECL vec<3, T, Q> glm::axis | ( | qua< T, Q > const & | x | ) |

Returns the q rotation axis.

Template Parameters

  T | A floating-point scalar type
  Q | A value from qualifier enum